// #autoload
// #name = HalSensor
// #version = 2.0
// #date = February 16, 2003
// #author = Halide
// #warrior = Halide
// #credit = Bluez, for adding sounds and the new update; Thanks for your help!
// #email = halide@tribes2.org
// #web = http://halide.tribes-universe.com/
// #description = Radar sensor for reticle.
// #category = Halide's Scripts
// #config = HalSensorConfig

if(!isObject(HalSensor))
{
	new ScriptObject(HalSensor)
	{
		class = HalSensor;
		version = "2.0";
	};
}

//create dummy folder for drop in sounds....
if (!isfile("audio/HalSensor/HalSensorSounds.txt")) {
		%file = new FileObject();
		%file.openForWrite("audio/HalSensor/HalSensorSounds.txt");
		%file.writeLine("Place any wav here to use in conjunction with HalSensor....");
		%file.close();
		%file.delete();
	}

function HalSensorToggle(%val)
{
	if(!%val)
		return;

	$HalPref::Sensor::Enabled = !$HalPref::Sensor::Enabled;

	alxPlay(sButtonOver, 0, 0, 0);

	if($HalPref::Sensor::Enabled)
		addMessageHudLine("\c2HalSensor enabled.");
	else
		addMessageHudLine("\c2HalSensor disabled.");

	HalSensorHud.setVisible(HalSensor.active && $firstPerson);
}

// START package HalSensor
package	HalSensor
{

	function HalSensor::Detectedtest(%this)
	{
		DETECT_testbutton.setActive( false );
		%detectsound =  "HalSensor/" @ (HalDetectSound.getTextById($HalPref::Sensor::Detected)) @ ".wav";
		%detected = alxCreateSource(AudioGui, %detectsound);
		alxPlay(%detected);

		%delay = alxGetWaveLen( %detectsound );
		$DetectTest = DETECT_testbutton.schedule( %delay,  setActive, true);
	}

	function HalSensor::Cleartest(%this)
	{
		CLEAR_testbtn.setActive( false );
		%clearsound = "HalSensor/" @ (HalClearSound.getTextById($HalPref::Sensor::Clear)) @ ".wav";
		%clear = alxCreateSource(AudioGui, %clearsound);
		alxPlay(%clear);

		%delay = alxGetWaveLen( %clearsound );
		$ClearTest = CLEAR_testbtn.schedule( %delay, setActive, true);
	}

	function HalSensor::setPrefs(%this)
	{
		if(isFile("prefs/HalPrefs.cs") && !$HalPrefsLoaded)
		{
			exec("prefs/HalPrefs.cs");
			$HalPrefsLoaded = true;
		}

		if($HalPref::Sensor::Version $= "")
		{
			$HalPref::Sensor::Version = HalSensor.version;
			$HalPref::Sensor::Enabled = true;
			$HalPref::Sensor::Type = 0;
			$HalPref::Sensor::Opacity = 0.25;
			$HalPref::Sensor::Pulse = true;
			$HalPref::Sensor::PulseRate = 1000;
			$HalPref::Sensor::Sound = true;
			$HalPref::Sensor::Detected = 1;
			$HalPref::Sensor::Clear = 0;
		}
	}

	function clientCmdSetStationKeys(%inStation)
	{
		parent::clientCmdSetStationKeys(%inStation);

		HalSensorHud.setVisible(HalSensor.active && !%inStation);
	}

	function hudFirstPersonToggled()
	{
		parent::hudFirstPersonToggled();

		HalSensorHud.setVisible(HalSensor.active && $firstPerson);
	}

	function SensorHud::update(%this)
	{
		parent::update(%this);

		if(!$HalPref::Sensor::Enabled)
			return;

		HalSensor.active = %this.ping || %this.jam;
		HalSensorHud.color = %this.color;
		HalSensorHud.setVisible(HalSensor.active && $firstPerson);
		
		if(!$HalPref::Sensor::Sound) return;
		
		if($HalPref::Sensor::Sound)
		{
			if(HalSensor.active) {
				%detectsound =  "HalSensor/" @ (HalDetectSound.getTextById($HalPref::Sensor::Detected)) @ ".wav";
				%detected = alxCreateSource(AudioGui, %detectsound);
				alxPlay(%detected); }
			else {
				%clearsound = "HalSensor/" @ (HalClearSound.getTextById($HalPref::Sensor::Clear)) @ ".wav";
				%clear = alxCreateSource(AudioGui, %clearsound);
				alxPlay(%clear); }
		}
	}

	function HalSensorHud::setup(%this)
	{
		%this.pulse = $HalPref::Sensor::Pulse;
		%this.pulseRate = $HalPref::Sensor::PulseRate;
		%this.opacity = $HalPref::Sensor::Opacity;
		%this.setBitmap("gui/HalSensor_" @ %this.type[$HalPref::Sensor::Type] @ ".png");
	}
	
	function HalSensor::setup(%this)
	{
		if(%this.setup)
			return;

		%this.setPrefs();

		exec("gui/HalSensorConfig.gui");

		HalSensorConfigType.add("Ring - Soft", 0);
		HalSensorConfigType.add("Ring - Hard", 1);
		HalSensorConfigType.add("Dot - Soft", 2);
		HalSensorConfigType.add("Dot - Hard", 3);
		HalSensorConfigType.add("Arrows - Soft", 4);
		HalSensorConfigType.add("Arrows - Hard", 5);
		
		HalDetectSound.clear();

		%id = 0;
		for ( %file = findFirstFile( "audio/HalSensor/*.wav" ); %file !$= ""; %file = findNextFile( "audio/HalSensor/*.wav" ) ) {
			HalDetectSound.add(fileBase( %file ), %id, 1);
			if(fileBase( %file ) $= $HalPref::Sensor::Detected) {
				HalDetectSound.setSelected(%id);
			}
			%id++;
		}

		HalClearSound.clear();

		%id = 0;
		for ( %file = findFirstFile( "audio/HalSensor/*.wav" ); %file !$= ""; %file = findNextFile( "audio/HalSensor/*.wav" ) ) {
			HalClearSound.add(fileBase( %file ), %id, 1);
			if(fileBase( %file ) $= $HalPref::Sensor::Clear) {
				HalClearSound.setSelected(%id);
			}
			%id++;
		}

		HalSensorConfigType.setSelected($HalPref::Sensor::Type);
		HalSensorConfigOpacitySlider.setValue($HalPref::Sensor::Opacity);
		HalSensorConfigPulseSlider.setValue($HalPref::Sensor::PulseRate);
		HalSensorConfigPulseSlider.setActive($HalPref::Sensor::Pulse);
		HalDetectSound.setSelected($HalPref::Sensor::Detected);
		HalClearSound.setSelected($HalPref::Sensor::Clear);
		
		new HudPulsingBitmap(HalSensorHud)
		{
			type[0] = "ring_soft";
			type[1] = "ring_hard";
			type[2] = "dot_soft";
			type[3] = "dot_hard";
			type[4] = "arrows_soft";
			type[5] = "arrows_hard";

			profile = "GuiDefaultProfile";
			horizSizing = "right";
			vertSizing = "bottom";
			position = "0 0";
			extent = "256 256";
			minExtent = "8 8";
			visible = "0";
			hideCursor = "0";
			bypassHideCursor = "0";
			helpTag = "0";
			fillColor = "0.250000 0.250000 0.250000 0.250000";
			frameColor = "0.000000 1.000000 0.000000 1.000000";
			opacity = "0.25";
			autoCenter = "1";
			autoResize = "1";
			flipVertical = "0";
			flipHorizontal = "0";
			color = "255 22 22 255";
			pulse = "1";
			pulseRate = "1000";
		};

		retCenterHud.add(HalSensorHud);

		HalSensorHud.setup();
		%this.setup = true;
	}

	function HalSensorConfig::onWake(%this)
	{
		// stop console error
	}

	function HalSensorConfig::updateOpacity(%this)
	{
		$HalPref::Sensor::Opacity = (%value = HalSensorConfigOpacitySlider.getValue());
		HalSensorConfigOpacityText.setValue(mFormatFloat(%value * 100, "%.f") @ "%");
	}

	function HalSensorConfig::updatePulse(%this)
	{
		$HalPref::Sensor::PulseRate = (%value = HalSensorConfigPulseSlider.getValue());
		HalSensorConfigPulseText.setValue(mFormatFloat(%value / 1000, "%.1f") @ " sec");
	}

	function OptionsDlg::onWake(%this)
	{
		if(!HalSensor.bind)
		{
			$RemapName[$RemapCount] = "HalSensor Toggle";
			$RemapCmd[$RemapCount] = "HalSensorToggle";
			$RemapCount++;

			HalSensor.bind = true;
		}

		parent::onWake(%this);
	}

	function DispatchLaunchMode()
	{
		parent::DispatchLaunchMode();

		HalSensor.setup();
	}

	function quit()
	{
		if(!$HalPrefsSaved)
		{
			export("$HalPref::*", "prefs/HalPrefs.cs", false);
			$HalPrefSaved = true;
		}

		parent::quit();
	}

// END package HalSensor
};
activatePackage(HalSensor);

if($AutoloadExecuted)
	HalSensor.setup();
